/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#include "albumview.h"
#include "mpd.h"
#include "stringlistmodel.h"

AlbumView::AlbumView(QWidget *parent) : StringListView(parent) {
	setObjectName("albumview");
}

void AlbumView::selectionChanged(const QItemSelection &s, const QItemSelection &u) {
	StringListView::selectionChanged(s, u);
	QModelIndexList indexes = selectedIndexes();

	QStringList albums = m_model->stringList(indexes);
	foreach (QString u, albums) {
		if (u.isNull()) {
			emit filterChanged(QRegExp());
			return;
		}
	}
	QString reg;
	foreach(QString u, albums) {
		if (u.isEmpty())
			reg += "^$|";
		else
			reg += QRegExp::escape(u) + "|";
	}
	emit filterChanged(QRegExp(reg.left(reg.size()-1)));
}

MPDSongList AlbumView::getSelectedSongs() {
	QStringList albums = m_model->stringList(selectedIndexes());
	albums.sort();
	MPDSongList ret;
	foreach(QString album, albums) {
		if (album.isNull()) {
			foreach(QString art, m_artists.keys().toSet().toList()) {
				ret << m_mpd->songsByArtist(art);
			}
			return ret;
		}
		ret << m_mpd->songsByAlbum(album, m_artists.key(album));
	}
	return ret;
}

void AlbumView::setStrings(QMultiMap<QString, QString> map) {
	m_artists = map;
	QStringList albums = map.values().toSet().toList();
	albums.sort();
	m_model->setStringList(albums);
	setCurrentIndex(m_model->index(0));
}

void AlbumView::filter(const QString &needle) {
	QStringList albums = m_artists.values();
	albums = albums.filter(QRegExp(needle, Qt::CaseInsensitive));
	albums.sort();
	m_model->setStringList(albums);
}
