/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#include "artistview.h"
#include "mpd.h"
#include "stringlistmodel.h"

ArtistView::ArtistView(QWidget *parent) : StringListView(parent) {
	setObjectName("artistview");
	connect(m_mpd, SIGNAL(artistsUpdated(QStringList)), this, SLOT(setStrings(QStringList)));
}

void ArtistView::selectionChanged(const QItemSelection &s, const QItemSelection &u) {
	StringListView::selectionChanged(s, u);
	QModelIndexList indexes = selectedIndexes();

	QMultiMap<QString, QString> res;
	foreach (QString artist, m_model->stringList(indexes)) {
		QStringList albums = m_mpd->albums(artist);
		foreach (QString album, albums) {
			res.insert(artist, album);
		}
	}
	if (res.isEmpty()) {
		emit selected(res);
		return;
	}

	// Emit to albums list
	emit selected(res);
	
	// Emit to songlist
	QStringList uniqe = QStringList::fromSet(res.keys().toSet());
	foreach (QString u, uniqe) {
		if (u.isNull()) {
			emit filterChanged(QRegExp());
			return;
		}
	}
	QString reg;
	foreach(QString u, uniqe) {
		if (u.isEmpty())
			reg += "^$|";
		else
			reg += QRegExp::escape(u) + "|";
	}
	emit filterChanged(QRegExp(reg.left(reg.size()-1)));
}

MPDSongList ArtistView::getSelectedSongs() {
	QStringList artists = m_model->stringList(selectedIndexes());
	MPDSongList ret;
	foreach(QString artist, artists) {
		if (artist.isNull()) {
			return m_mpd->songs();
		}
		ret << m_mpd->songsByArtist(artist);
	}
	return ret;
}

void ArtistView::setStrings(QStringList sl) {
	m_model->setStringList(m_strings = sl);
	setCurrentIndex(m_model->index(0));
	selectionChanged();
}
