/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef CONFIG_H
#define CONFIG_H

#include "mpdsonglist.h"
#include "serverinfo.h"
#include <QFont>
#include <QSettings>

class QStringList;

class Config : public QSettings {
	Q_OBJECT
private:
	static Config *m_instance;
	Config();

public:
	static Config *instance();

	// Server settings
	void setAutoconnect(bool);
	void setServers(ServerInfoList);
	ServerInfoList servers();
	ServerInfo server(QString = QString::null);
	void setReconnect(bool);
	void setReconnectTime(int);
	void setTimeoutTime(int);
	bool autoconnect();
	bool reconnect();
	int reconnectTime();
	int timeoutTime();

	// Look and feel
	void setAutoResizeColumns(bool);
	void setEnqueue(bool);
	void setFont(QFont);
	void setOpaqueResize(bool);
	void setRecurse(bool);
	void setScrollToPlaying(bool);
	bool autoResizeColumns();
	bool enqueue();
	QFont font();
	bool opaqueResize();
	bool recurse();
	bool scrollToPlaying();

	// Language
	void setLocale(QString);
	void setTranslation(bool);
	QString locale();
	bool translation();

	// Popups
	void setNotificationsEnabled(bool);
	void setNotificationsPosition(int);
	void setNotificationsTimeout(int);
	bool notificationsEnabled();
	int notificationsPosition();
	int notificationsTimeout();

	// System tray
	void setMinimizeToTray(bool);
	void setStartHidden(bool);
	void setTrayIconEnabled(bool);
	bool minimizeToTray();
	bool startHidden();
	bool trayIconEnabled();

	// Auto player
	void setAutoAddCount(int);
	void setAutoAddPos(int);
	void setAutoAddSongs(bool);
	void setAutoRemoveSongs(bool);
	int autoAddCount();
	int autoAddPos();
	bool autoAddSongs();
	bool autoRemoveSongs();

	// Window and splitter sizes
	void setDirectorySplitterSizes(QByteArray);
	void setLibraryHSplitterSizes(QByteArray);
	void setLibraryVSplitterSizes(QByteArray);
	void setMainSplitterSizes(QByteArray);
	void setPlaylistsSplitterSizes(QByteArray);
	void setWindowSize(QSize);
	QByteArray directorySplitterSizes();
	QByteArray libraryHSplitterSizes();
	QByteArray libraryVSplitterSizes();
	QByteArray mainSplitterSizes();
	QByteArray playlistsSplitterSizes();
	QSize windowSize();

	// View's properties
	void setHeaderViewState(QString, QByteArray);
	QByteArray headerViewState(QString);

	// Radio stations
	void addRadioStation(QString title, QString url);
	void removeRadioStations(MPDSongList stations);
	MPDSongList radioStations();

	// Guesser
	void setGuessPattern(QString);
	void setTagGuesserEnabled(bool);
	void setTestFilename(QString);
	QString guessPattern();
	bool tagGuesserEnabled();
	QString testFilename();

signals:
	void autoResizeChanged(bool);
	void fontChanged(QFont);
	void opaqueResizeChanged(bool);
	void serverListChanged(ServerInfoList);
	void trayIconChanged(bool);
};

#endif
