/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#include "headerview.h"
#include "jumptosongdialog.h"
#include "mpdsong.h"
#include "mpdsongmodel.h"

JumpToSongDialog::JumpToSongDialog(QWidget *parent, MPDSongList songs, int id) : QDialog(parent) {
	setupUi(this);
	HeaderView *hv = new HeaderView(this, HeaderView::PLAYLISTSVIEW, true);
	m_model = new MPDSongModel(this, hv);
	m_model->setSongs(songs);
	searchView->setModel(m_model);
	searchView->setHeader(hv);
	hv->restore();
	searchView->setCurrentIndex(m_model->indexId(id));

	// signals and slots connections
	connect(searchView, SIGNAL(activated(const QModelIndex &)), this, SLOT(indexActivated(const QModelIndex &)));
	connect(clearFilter, SIGNAL(clicked()), filter, SLOT(clear()));

	show();
}

void JumpToSongDialog::indexActivated(const QModelIndex &index) {
	if (!index.isValid())
		return;
	foreach(MPDSong *s, m_model->songs(index)) {
		done(s->id());
		break;
	}
}

void JumpToSongDialog::on_cancel_clicked() {
	done(QDialog::Rejected);
}

void JumpToSongDialog::on_filter_textChanged(const QString &needle) {
	m_model->setFilter(needle, qobject_cast<HeaderView*>(searchView->header())->visibleColumns());
	searchView->setCurrentIndex(m_model->index(0, 0));
}

void JumpToSongDialog::on_ok_clicked() {
	QModelIndex i = searchView->currentIndex();
	if (!i.isValid()) {
		done(QDialog::Rejected);
		return;
	}
	foreach(MPDSong *s, m_model->songs(i)) {
		done(s->id());
	}
}
