/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#include "librarypanel.h"
#include "config.h"
#include "mpd.h"

LibraryPanel::LibraryPanel() {
	setupUi(this);
	m_config = Config::instance();

	connect(artistView, SIGNAL(selected(QMultiMap<QString, QString>)),
	        albumView, SLOT(setStrings(QMultiMap<QString, QString>)));
	connect(artistView, SIGNAL(filterChanged(QRegExp)), songView, SLOT(setArtistFilter(QRegExp)));
	connect(albumView, SIGNAL(filterChanged(QRegExp)), songView, SLOT(setAlbumFilter(QRegExp)));

	connect(artistFilter, SIGNAL(textChanged(const QString &)), artistView, SLOT(filter(const QString &)));
	connect(clearArtistFilter, SIGNAL(clicked()), artistFilter, SLOT(clear()));
	connect(albumFilter, SIGNAL(textChanged(const QString &)), albumView, SLOT(filter(const QString &)));
	connect(clearAlbumFilter, SIGNAL(clicked()), albumFilter, SLOT(clear()));
	connect(clearSongFilter, SIGNAL(clicked()), songFilter, SLOT(clear()));
	connect(songFilter, SIGNAL(textChanged(const QString &)), songView, SLOT(setTitleFilter(const QString &)));
	connect(MPD::instance(), SIGNAL(songsUpdated(MPDSongList)), songView, SLOT(setSongs(MPDSongList)));

	connect(m_config, SIGNAL(opaqueResizeChanged(bool)), this, SLOT(opaqueResizeChanged(bool)));

	opaqueResizeChanged(m_config->opaqueResize());
	libraryVSplit->restoreState(m_config->libraryVSplitterSizes());
	libraryHSplit->restoreState(m_config->libraryHSplitterSizes());
}

void LibraryPanel::on_libraryHSplit_splitterMoved(int, int) {
	m_config->setLibraryHSplitterSizes(libraryHSplit->saveState());
}

void LibraryPanel::on_libraryVSplit_splitterMoved(int, int) {
	m_config->setLibraryVSplitterSizes(libraryVSplit->saveState());
}

void LibraryPanel::opaqueResizeChanged(bool o) {
	libraryHSplit->setOpaqueResize(o);
	libraryVSplit->setOpaqueResize(o);
}

