/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef MPDSONG_H
#define MPDSONG_H

#include "libmpdclient.h"
#include <QString>

class MPDSong {
public:
	enum Type { ERROR, SONG, STREAM, PLAYLIST, PLAYLISTSONG, PLAYLISTSTREAM, UNKNOWN };

private:
	int m_pos, m_secs, m_id;
	MPDSong::Type m_type;
	QString m_album, m_artist, m_track, m_date, m_genre, m_composer, m_url, m_title, m_time;
	void parsePlaylist(QString);
	void parseSong(mpd_Song *);

public:
	// Create blank song
	MPDSong();
	// Create song from a mpd_InfoEntity typically song or playlist
	MPDSong(mpd_InfoEntity *);
	// Create stream song, just url and title
	static MPDSong *createStream(QString title, QString url);
	// Create playlist song, just url
	static MPDSong *createPlaylist(QString url);
	// This one is for creating dummy songs for pattern testing
	static MPDSong *createTest(QString url);

	MPDSong::Type type() {
		return m_type;
	}
	int pos() {
		return m_pos;
	}
	int secs() {
		return m_secs;
	}
	int id() {
		return m_id;
	}
	void setArtist(QString artist) {
		m_artist = artist;
	}
	QString artist() {
		return m_artist;
	}
	void setAlbum(QString album) {
		m_album = album;
	}
	QString album() {
		return m_album;
	}
	void setTrack(QString track) {
		m_track = track;
	}
	QString track() {
		return m_track;
	}
	QString filename() {
		return m_url.section('/', -1, -1);
	}
	void setUrl(QString url) {
		m_url = url;
	}
	QString url() {
		return m_url;
	}
	QString time();
	void setTitle(QString title) {
		m_title = title;
	}
	QString title() {
		return m_title;
	}
	QString date() {
		return m_date;
	}
	QString genre() {
		return m_genre;
	}
	QString composer() {
		return m_composer;
	}
	bool equals(MPDSong *);
};

#endif
