/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef MPDSONGMODEL_H
#define MPDSONGMODEL_H

#include "headerview.h"
#include "mpdsonglist.h"
#include <QAbstractTableModel>
#include <QRegExp>
#include <QStringList>

class MPDSongModel : public QAbstractTableModel {
private:
	Qt::ItemFlags m_extraFlags;
	int m_playingId;
	HeaderView::View m_view;
	MPDSongList m_visible, m_all;
	QRegExp m_albumFilter, m_artistFilter, m_titleFilter;
	QList<HeaderView::Column> m_columns;
	QList<HeaderView::Column> m_filterColumns;
	void filter();
	MPDSong *song(const QModelIndex &);

public:
	MPDSongModel(QObject *, HeaderView *);
	int columnCount(const QModelIndex & = QModelIndex()) const;
	int rowCount(const QModelIndex & = QModelIndex()) const;
	QVariant data(const QModelIndex &, int) const;
	QVariant headerData(int, Qt::Orientation, int = Qt::DisplayRole) const;
	Qt::ItemFlags flags(const QModelIndex &) const;
	void setExtraFlags(Qt::ItemFlags);

	QModelIndex indexId(int id);

	void setAlbumFilter(QRegExp);
	void setArtistFilter(QRegExp);
	void setFilter(QString, QList<HeaderView::Column> cols);

	void sort(int column, Qt::SortOrder order = Qt::AscendingOrder);

	void setSongs(MPDSongList);
	MPDSongList songs();
	MPDSongList songs(QModelIndexList);
	MPDSongList songs(const QModelIndex &);
	MPDSong *lastSong();
	void setPlaying(MPDSong *);
	int playingId();
	MPDSongList unSelectedSongs(QModelIndexList);
	QString columnName(HeaderView::Column) const;
};
#endif
