/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef MPDSONGVIEW_H
#define MPDSONGVIEW_H

#include "headerview.h"
#include "mpdsonglist.h"
#include <QTreeView>

class Config;
class MPD;
class MPDSongModel;

class MPDSongView : public QTreeView {
	Q_OBJECT

protected:
	bool m_midButtonDrag;
	Config *m_config;
	HeaderView *m_header;
	HeaderView::View m_view;
	MPD *m_mpd;
	MPDSongModel *m_model;
	QMenu *m_menu;

	QAction *m_enqueueAction, *m_playAction, *m_informationAction;
	void contextMenuEvent(QContextMenuEvent *);
	void startDrag(Qt::DropActions);
	void selectionChanged(const QItemSelection & = QItemSelection(), const QItemSelection & = QItemSelection());
	void mouseMoveEvent(QMouseEvent *);
	void mousePressEvent(QMouseEvent *);
	void mouseReleaseEvent(QMouseEvent *);
	MPDSongView(QWidget *, HeaderView::View, bool = true);

public slots:
	void setAlbumFilter(QRegExp);
	void setArtistFilter(QRegExp);
	void setTitleFilter(const QString &);

protected slots:
	void enqueue();
	void indexActivated(const QModelIndex &);
	void information();
	void play();
	void setSongs(MPDSongList);
};

class FileView : public MPDSongView {
public:
	FileView(QWidget *parent) : MPDSongView(parent, HeaderView::FILEVIEW) {}}
;

class SongView : public MPDSongView {
public:
	SongView(QWidget *parent) : MPDSongView(parent, HeaderView::SONGVIEW) {}}
;

class PlaylistsContentView : public MPDSongView {
public:
	PlaylistsContentView(QWidget *parent) : MPDSongView(parent, HeaderView::PLAYLISTSCONTENTVIEW) {}}
;

#endif
