/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#include "mpd.h"
#include "multimediakeys.h"

#ifdef Q_WS_X11
#include <QDesktopWidget>
#include <QX11Info>

#define XF86AUDIO_VOLUP 176
#define XF86AUDIO_VOLDN 174
#define XF86AUDIO_MEDIA 129
#define XF86AUDIO_PLAY 162
#define XF86AUDIO_STOP 164
#define XF86AUDIO_NEXT 153
#define XF86AUDIO_PREV 144

extern "C" {
	static int XGrabErrorHandler(Display *, XErrorEvent *e) {
		if ( e->error_code != BadAccess )
			qWarning("grabKey: got X error %d instead of BadAccess", e->type);
		return 0;
	}
}
#endif

MultiMediaKeys::MultiMediaKeys() {
#ifdef Q_WS_X11
	Display *dpy = QX11Info::display();
	XSync(dpy, 0);
	XErrorHandler savedErrorHandler = XSetErrorHandler(XGrabErrorHandler);
	WId rootWindowId = QApplication::desktop()->winId();

	// Grab multimedia keys
	XGrabKey(dpy, XF86AUDIO_PLAY, AnyModifier, rootWindowId, 1, GrabModeAsync, GrabModeAsync);
	XGrabKey(dpy, XF86AUDIO_STOP, AnyModifier, rootWindowId, 1, GrabModeAsync, GrabModeAsync);
	XGrabKey(dpy, XF86AUDIO_PREV, AnyModifier, rootWindowId, 1, GrabModeAsync, GrabModeAsync);
	XGrabKey(dpy, XF86AUDIO_NEXT, AnyModifier, rootWindowId, 1, GrabModeAsync, GrabModeAsync);
	XGrabKey(dpy, XF86AUDIO_MEDIA, AnyModifier, rootWindowId, 1, GrabModeAsync, GrabModeAsync);
	XGrabKey(dpy, XF86AUDIO_VOLUP, AnyModifier, rootWindowId, 1, GrabModeAsync, GrabModeAsync);
	XGrabKey(dpy, XF86AUDIO_VOLDN, AnyModifier, rootWindowId, 1, GrabModeAsync, GrabModeAsync);
	XSync(dpy, 0);
	XSetErrorHandler(savedErrorHandler);
#endif
}

MultiMediaKeys::~MultiMediaKeys() {
#ifdef Q_WS_X11
	// Ungrab multimedia keys
	Display *dpy = QX11Info::display();
	WId rootWindowId = QApplication::desktop()->winId();
	XUngrabKey(dpy, XF86AUDIO_PLAY, AnyModifier, rootWindowId);
	XUngrabKey(dpy, XF86AUDIO_STOP, AnyModifier, rootWindowId);
	XUngrabKey(dpy, XF86AUDIO_PREV, AnyModifier, rootWindowId);
	XUngrabKey(dpy, XF86AUDIO_NEXT, AnyModifier, rootWindowId);
	XUngrabKey(dpy, XF86AUDIO_MEDIA, AnyModifier, rootWindowId);
	XUngrabKey(dpy, XF86AUDIO_VOLUP, AnyModifier, rootWindowId);
	XUngrabKey(dpy, XF86AUDIO_VOLDN, AnyModifier, rootWindowId);
#endif
}

#ifdef Q_WS_X11
bool MultiMediaKeys::x11EventFilter(XEvent *xevent) {
	XKeyEvent *keyevent = (XKeyEvent *)xevent;

	if (xevent->type != KeyRelease)
		return false;

	switch (keyevent->keycode) {

	case XF86AUDIO_PLAY:
		MPD::instance()->togglePlay();
		return true;

	case XF86AUDIO_STOP:
		MPD::instance()->stop();
		return true;

	case XF86AUDIO_NEXT:
		MPD::instance()->next();
		return true;

	case XF86AUDIO_PREV:
		MPD::instance()->prev();
		return true;

	case XF86AUDIO_MEDIA:
		emit showHide();
		return true;

	case XF86AUDIO_VOLUP:
		MPD::instance()->volumeUp();
		return true;

	case XF86AUDIO_VOLDN:
		MPD::instance()->volumeDown();
		return true;
	}

	return false;
}
#endif
