/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#include "config.h"
#include "mpd.h"
#include "mpdsong.h"
#include "notifications.h"
#include "passivepopup.h"
#include "richtext.h"
#include <QApplication>
#include <QDesktopWidget>
#include <QPixmap>

Notifications::Notifications(QObject *parent) : QObject(parent) {
	setObjectName("notifications");
	config = Config::instance();
	MPD *mpd = MPD::instance();
	connect(mpd, SIGNAL(playingSongUpdated(MPDSong*)), this, SLOT(playingSongUpdated(MPDSong*)));
	connect(mpd, SIGNAL(disconnected(QString)), this, SLOT(disconnected(QString)));
}

void Notifications::disconnected(QString message) {
	if (message.isEmpty())
		return;
	QString popmsg = QString("<b>%1</b><br />%2").arg(tr("Error")).arg(message);
	PassivePopup::Position pos = (PassivePopup::Position)config->notificationsPosition();
	int timeout = config->notificationsTimeout();
	if (config->notificationsEnabled() && timeout > 0)
		new PassivePopup("QMPDClient", popmsg, QPixmap(":/icons/qmpdclient22.png"), pos, timeout);
}

void Notifications::playingSongUpdated(MPDSong *s) {
	if (!s) {
		prevUrl = QString::null;
		return;
	}

	if (prevUrl == s->url())
		return;

	int desktopWidth = QApplication::desktop()->width();
	QString title = formattedText("<b>", s->title(), "</b>", desktopWidth/2) + "<br />";
	QString artist = formattedText("", s->artist(), "", desktopWidth/4);
	QString album = formattedText("", s->album(), "", desktopWidth/4);
	if (!artist.isEmpty())
		title += "<b>" + artist + "</b>";
	if (!artist.isEmpty() && !album.isEmpty())
		title += " - ";
	if (!album.isEmpty())
		title += "<b>" + album + "</b>";

	PassivePopup::Position pos = (PassivePopup::Position)config->notificationsPosition();
	int timeout = config->notificationsTimeout();
	if (config->notificationsEnabled() && timeout > 0) {
		new PassivePopup("QMPDClient", title, QPixmap(":/icons/qmpdclient22.png"), pos, timeout);
	}
	prevUrl = s->url();
}
