/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#include "playlistspanel.h"
#include "config.h"

PlaylistsPanel::PlaylistsPanel() {
	setupUi(this);
	m_config = Config::instance();

	connect(deletePlaylistButton, SIGNAL(clicked()), playlistsView, SLOT(deletePlaylist()));
	connect(playlistFilter, SIGNAL(textChanged(const QString &)), playlistsView, SLOT(setTitleFilter(const QString &)));
	connect(clearPlaylistFilter, SIGNAL(clicked()), playlistFilter, SLOT(clear()));
	connect(playlistsView, SIGNAL(toggleActions(bool)), deletePlaylistButton, SLOT(setEnabled(bool)));
	connect(playlistsView, SIGNAL(playlistChanged(MPDSongList)), playlistsContentView, SLOT(setSongs(MPDSongList)));
	connect(playlistContentFilter, SIGNAL(textChanged(const QString &)), playlistsContentView, SLOT(setTitleFilter(const QString &)));
	connect(clearPlaylistContentFilter, SIGNAL(clicked()), playlistContentFilter, SLOT(clear()));
	connect(m_config, SIGNAL(opaqueResizeChanged(bool)), this, SLOT(opaqueResizeChanged(bool)));

	opaqueResizeChanged(m_config->opaqueResize());
	playlistsSplit->restoreState(m_config->playlistsSplitterSizes());
}

void PlaylistsPanel::on_playlistsSplit_splitterMoved(int, int) {
	m_config->setPlaylistsSplitterSizes(playlistsSplit->saveState());
}

void PlaylistsPanel::opaqueResizeChanged(bool o) {
	playlistsSplit->setOpaqueResize(o);
}
