/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef PLAYLISTVIEW_H
#define PLAYLISTVIEW_H

#include "mpdsongview.h"
#include <QLine>

class PlaylistView : public MPDSongView {
	Q_OBJECT

private:
	QAction *m_cropAction, *m_randomAction, *m_removeAction, *m_repeatAction;
	// DND variables
	QLine m_dropLine;
	int m_dropPos;
	bool m_hidden;

	void selectionChanged(const QItemSelection & = QItemSelection(), const QItemSelection & = QItemSelection());
	// DND methods
	void dragEnterEvent(QDragEnterEvent *);
	void dropEvent(QDropEvent *);
	void dragLeaveEvent(QDragLeaveEvent *);
	void dragMoveEvent(QDragMoveEvent *);
	bool hasDroppableFormat(const QMimeData *);
	void startDrag(Qt::DropActions);
	// Reimplemented to draw drop point
	void drawRow(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const;
	void scrollTo(QModelIndex = QModelIndex());
	void paintEvent(QPaintEvent *);
	void hideEvent(QHideEvent *);

public:
	PlaylistView(QWidget *);

private slots:
	void indexActivated(const QModelIndex &);
	void information();
	void jumpToSong();
	void setSong(MPDSong *);
	void setPlaylist(MPDSongList);

public slots:
	void cropItems();
	void removeItems();
	void savePlaylist();

signals:
	void toggleActions(bool);
};
#endif
