/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#include "config.h"
#include "dynamicplaylist.h"
#include "mainwindow.h"
#include "mpd.h"
#include "multimediakeys.h"
#include "notifications.h"
#include "qmpdclient.h"
#include "reconnect.h"
#include "trayicon.h"
#include <QLibraryInfo>
#include <QTranslator>

QMPDClient::QMPDClient(int &argc, char **argv) : QApplication(argc, argv), multiMediaKeys(0), trayIcon(0) {
	setObjectName("qmpdclient");
	setApplicationName("QMPDClient");
	setOrganizationName("QMPDClient");

	config = Config::instance();
	// Translation
	if (config->translation()) {
		QTranslator *translator = new QTranslator(this);
		QTranslator *qtTranslator = new QTranslator(this);
		if (translator->load(QString("qmpdclient_")+config->locale(), ":/translations/", QString(), ".qm"))
			installTranslator(translator);
		if (qtTranslator->load(QString("qt_")+config->locale(), QLibraryInfo::location(QLibraryInfo::TranslationsPath)))
			installTranslator(qtTranslator);
	}

	mpd = MPD::instance();
	mpd->start();

	// Start services
	new DynamicPlaylist(this);
	new Notifications(this);
	new Reconnect(this);
	multiMediaKeys = new MultiMediaKeys();
	trayIcon = TrayIcon::instance();
	
	// Create mainwin
	mainWindow = new MainWindow();
	
	connect(this, SIGNAL(lastWindowClosed()), this, SLOT(quit()));
	connect(mainWindow, SIGNAL(mainWindowClose(QCloseEvent *)), trayIcon, SLOT(mainWindowClose(QCloseEvent *)));
	connect(trayIcon, SIGNAL(showHide()), mainWindow, SLOT(showHide()));
	connect(multiMediaKeys, SIGNAL(showHide()), mainWindow, SLOT(showHide()));

	mainWindow->setVisible(!trayIcon->hideOnStart());
	if (config->autoconnect()) // Autoconnect?
		mpd->connectToMPD(config->servers().first());
}

QMPDClient::~QMPDClient() {
	// Stop MPD-thread's event loop
	mpd->quit();

	// Stopping MPD takes a while, do something useful meanwhile.
	if (trayIcon)
		delete trayIcon;
	if (multiMediaKeys)
		delete multiMediaKeys;
	delete mainWindow;
	delete config;

	// Make sure MPD is stopped before delete
	mpd->wait();
	delete mpd;
}

#ifdef Q_WS_X11
bool QMPDClient::x11EventFilter(XEvent *xevent) {
	return multiMediaKeys->x11EventFilter(xevent);
}
#endif

int main(int argc, char **argv) {
	return QMPDClient(argc, argv).exec();
}
