/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#include "config.h"
#include "mpdsong.h"
#include "mpdsongmodel.h"
#include "radioview.h"
#include "ui_addradiodialog.h"
#include <QMenu>

RadioView::RadioView(QWidget *parent) : MPDSongView(parent, HeaderView::RADIOVIEW) {
	m_menu->addSeparator();
	m_menu->addAction(QPixmap(":/icons/add.png"), tr("&New..."), this, SLOT(newStation()));
	m_removeAction = m_menu->addAction(QPixmap(":/icons/remove.png"), tr("&Delete"), this, SLOT(deleteStation()));
	m_removeAction->setShortcut(Qt::Key_Delete);
	m_removeAction->setShortcutContext(Qt::WidgetShortcut);
	addAction(m_removeAction);

	// Load radio stations
	loadStations();
}

RadioView::~RadioView() {
	// Radio stations are not memory handled by MPD, so delete them here.
	MPDSongList stations = m_model->songs();
	while (!stations.isEmpty())
		delete stations.takeLast();
}

void RadioView::newStation() {
	QDialog *dia = new QDialog(this);
	Ui_AddRadioDialog *ard = new Ui_AddRadioDialog();
	ard->setupUi(dia);
	dia->resize(300, 100);
	if (dia->exec() == QDialog::Accepted) {
		if (!ard->title->text().isEmpty() && !ard->url->text().isEmpty()) {
			m_config->addRadioStation(ard->title->text(), ard->url->text());
			loadStations();
		}
	}
	delete dia;
}

void RadioView::selectionChanged(const QItemSelection &s, const QItemSelection &u) {
	MPDSongView::selectionChanged(s, u);
	bool t = selectedIndexes().size() > 0;
	m_removeAction->setEnabled(t);
	emit toggleActions(t);
}

void RadioView::loadStations() {
	MPDSongList stations = m_model->songs();
	// Delete previously loaded stations first
	while (!stations.isEmpty())
		delete stations.takeLast();
	m_model->setSongs(m_config->radioStations());
	m_model->sort(header()->sortIndicatorSection(), header()->sortIndicatorOrder());
	selectionChanged();
}

void RadioView::deleteStation() {
	m_config->removeRadioStations(m_model->songs(selectedIndexes()));
	loadStations();
}
