/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#include "config.h"
#include "metainfodialog.h"
#include "mpd.h"
#include "mpdsong.h"
#include "stringlistmodel.h"
#include "stringlistview.h"

#include <QContextMenuEvent>
#include <QMenu>

StringListView::StringListView(QWidget *parent) : QListView(parent),
		m_midButtonDrag(false),
		m_mpd(MPD::instance()),
m_menu(new QMenu(this)) {
	setModel(m_model = new StringListModel(this));

	m_enqueueAction = m_menu->addAction(QPixmap(":/icons/add.png"), tr("&Enqueue"), this, SLOT(enqueue()));
	m_playAction = m_menu->addAction(QPixmap(":/icons/play.png"), tr("&Play"), this, SLOT(play()));
	m_menu->addSeparator();
	m_informationAction = m_menu->addAction(QPixmap(":/icons/crystal/info.png"), tr("&Information..."), this, SLOT(information()));

	connect(this, SIGNAL(activated(const QModelIndex &)), this, SLOT(activated(const QModelIndex &)));
	selectionChanged();
}

void StringListView::selectionChanged(const QItemSelection &s, const QItemSelection &u) {
	QListView::selectionChanged(s, u);
	QModelIndexList indexes = selectedIndexes();
	m_enqueueAction->setEnabled(!indexes.isEmpty());
	m_informationAction->setEnabled(!indexes.isEmpty());
	m_playAction->setEnabled(!indexes.isEmpty());
}

void StringListView::activated(const QModelIndex &) {
	m_mpd->addSongs(getSelectedSongs(), Config::instance()->enqueue());
}

void StringListView::contextMenuEvent(QContextMenuEvent *e) {
	QModelIndex clicked = indexAt(e->pos());
	QModelIndexList indexes = selectedIndexes();
	if (indexes.isEmpty() || !indexes.contains(clicked))
		setCurrentIndex(indexAt(e->pos()));
	m_menu->popup(e->globalPos());
}

void StringListView::enqueue() {
	m_mpd->addSongs(getSelectedSongs(), true);
}

void StringListView::filter(const QString &needle) {
	m_model->setStringList(m_strings.filter(QRegExp(needle, Qt::CaseInsensitive)));
}

void StringListView::information() {
	new MetaInfoDialog(this, getSelectedSongs());
}

void StringListView::play() {
	m_mpd->addSongs(getSelectedSongs(), false);
}

void StringListView::startDrag(Qt::DropActions) {
	if (m_midButtonDrag)
		return;
	QDrag *drag = new QDrag(this);
	drag->setPixmap(QPixmap(":/icons/amarok/collection.png"));
	QString songs = "";
	foreach (MPDSong *song, getSelectedSongs()) {
		songs += song->url() + "\n";
	}
	if (songs.isEmpty())
		return;
	QMimeData *mimeData = new QMimeData();
	mimeData->setData("qmpdclient/song", songs.toUtf8());
	drag->setMimeData(mimeData);
	drag->start();
}

void StringListView::mouseMoveEvent(QMouseEvent *e) {
	QMouseEvent *e2 = e;
	if (m_midButtonDrag)
		e2 = new QMouseEvent(e->type(), e->pos(), Qt::LeftButton, e->buttons() | Qt::LeftButton, e->modifiers());
	QListView::mouseMoveEvent(e2);
}

void StringListView::mousePressEvent(QMouseEvent *e) {
	QMouseEvent *e2 = e;
	if (e->button() == Qt::MidButton) {
		m_midButtonDrag = true;
		e2 = new QMouseEvent(e->type(), e->pos(), Qt::LeftButton, e->buttons(), e->modifiers());
	}
	QListView::mousePressEvent(e2);
}

void StringListView::mouseReleaseEvent(QMouseEvent *e) {
	if (e->button() == Qt::MidButton)
		m_midButtonDrag = false;
	QListView::mouseReleaseEvent(e);
}
